==> dde-dock_5.4.10.orig.tar.xz: dde-dock-5.4.10/translations/dde-dock_fr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="fr" version="2.1">
<context>
    <name>AbstractPluginsController</name>
    <message>
        <source>The plugin %1 is not compatible with the system.</source>
        <translation>Le plugin %1 n&apos;est pas compatible avec le système.</translation>
    </message>
</context>
<context>
    <name>AppDragWidget</name>
    <message>
        <source>Remove</source>
        <translation>Retirer</translation>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>Paramètres Bluetooth</translation>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>Éteindre</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Allumer</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>Paramètres Bluetooth</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 connecté</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>Connexion...</translation>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>Eteint</translation>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>Ajouter une disposition de clavier</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>Date et heure</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>Affichage 12 heures</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>Affichage 24 heures</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>Réglages de l&apos;heure</translation>
    </message>
</context>
<context>
    <name>DeviceItem</name>
    <message>
        <source>Enable network</source>
        <translation>Activer le réseau</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Désactiver le réseau</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Paramètres réseau</translation>
    </message>
</context>
<context>
    <name>DialogManager</name>
    <message>
        <source>Are you sure you want to empty %1 items?</source>
        <translation>Êtes-vous sûr de vouloir supprimer %1 éléments ?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <source>This action cannot be restored</source>
        <translation>Cette action ne peut être restaurée</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown device</source>
        <translation>Périphérique inconnu</translation>
    </message>
    <message>
        <source>Unknown volume</source>
        <translation>Partition inconnue</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Disque</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Ouvrir</translation>
    </message>
    <message>
        <source>Unmount all</source>
        <translation>Tout démonter </translation>
    </message>
</context>
<context>
    <name>LauncherItem</name>
    <message>
        <source>Launcher</source>
        <translation>Lanceur</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Exit Safe Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dock - Safe Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The Dock is in safe mode, please exit to show it properly</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Fashion Mode</source>
        <translation>Mode dock</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>Mode étendu </translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Haut</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Bas</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Gauche</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Droite</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>Maintenir affiché</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>Maintenir caché</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>Masquage intelligemment</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Mode</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Emplacement</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Statut</translation>
    </message>
    <message>
        <source>Plugins</source>
        <translation>Extensions</translation>
    </message>
</context>
<context>
    <name>MultitaskingPlugin</name>
    <message>
        <source>Multitasking View</source>
        <translation>Vue multitâche</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Détacher du dock</translation>
    </message>
</context>
<context>
    <name>NetworkItem</name>
    <message>
        <source>Disable wired connection</source>
        <translation>Désactiver la connexion filaire</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>Activer la connexion filaire</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>Désactiver la connexion sans fil</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>Activer la connexion sans fil</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Désactiver le réseau</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>Activer le réseau</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Paramètres réseau</translation>
    </message>
    <message>
        <source>Device disabled</source>
        <translation>Périphérique désactivé </translation>
    </message>
    <message>
        <source>Wireless connection: %1</source>
        <translation>Connexion sans fil : %1</translation>
    </message>
    <message>
        <source>Wired connection: %1</source>
        <translation>Connexion filaire : %1</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Non connecté</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Connexion</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Connecté mais pas d’accès internet</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Câble réseau débranché</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Réseau sans fil</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Réseau filaire</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation>La connexion a échoué</translation>
    </message>
</context>
<context>
    <name>NetworkPlugin</name>
    <message>
        <source>Network</source>
        <translation>Réseau</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Réseau filaire</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Réseau filaire %1</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>Clavier virtuel</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Paramètres</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power</source>
        <translation>Alimentation</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Options d&apos;alimentation</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>Capacité  %1, %2 minutes restantes</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>Capacité %1, %2 heures et %3 minutes restantes</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>En charge %1, %2 minutes avant la charge complète</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>En charge %1, %2 heures et %3 minutes avant la charge complète</translation>
    </message>
    <message>
        <source>Charged</source>
        <translation>Chargé</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>Capacité %1</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>En charge %1</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>Capacité %1</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>Capacité %1, complètement chargé</translation>
    </message>
</context>
<context>
    <name>ShowDesktopPlugin</name>
    <message>
        <source>Show Desktop</source>
        <translation>Afficher le bureau</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Détacher du dock</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Power</source>
        <translation>Alimentation</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Arrêter</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Mise en veille </translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Mise en veille prolongée</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Verrouiller</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Déconnexion</translation>
    </message>
    <message>
        <source>Switch account</source>
        <translation>Changer de compte</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Options d&apos;alimentation</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Redémarrer</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Device</source>
        <translation>Périphérique</translation>
    </message>
</context>
<context>
    <name>SoundItem</name>
    <message>
        <source>Unmute</source>
        <translation>Réactiver le son</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Muet</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Paramètres sonores</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>Volume %1</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>Son</translation>
    </message>
</context>
<context>
    <name>TrashPlugin</name>
    <message>
        <source>Trash</source>
        <translation>Corbeille</translation>
    </message>
    <message>
        <source>Trash - %1 file</source>
        <translation>Corbeille - %1 fichier</translation>
    </message>
    <message>
        <source>Trash - %1 files</source>
        <translation>Corbeille - %1 fichiers</translation>
    </message>
</context>
<context>
    <name>TrashWidget</name>
    <message>
        <source>Open</source>
        <translation>Ouvrir</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>Vide</translation>
    </message>
</context>
<context>
    <name>TrayPlugin</name>
    <message>
        <source>System Tray</source>
        <translation>Zone de notification</translation>
    </message>
</context>
<context>
    <name>WirelessList</name>
    <message>
        <source>Wireless Network</source>
        <translation>Réseau sans fil</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Réseau sans fil %1</translation>
    </message>
</context>
</TS>

==> dde-dock_5.5.53.orig.tar.xz: dde-dock-5.5.53/translations/dde-dock_fr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fr">
<context>
    <name>AbstractPluginsController</name>
    <message>
        <source>The plugin %1 is not compatible with the system.</source>
        <translation>Le plugin %1 n&apos;est pas compatible avec le système.</translation>
    </message>
</context>
<context>
    <name>AirplaneModeApplet</name>
    <message>
        <source>Airplane Mode</source>
        <translation>Mode avion</translation>
    </message>
</context>
<context>
    <name>AirplaneModeItem</name>
    <message>
        <source>Airplane mode enabled</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Turn off</source>
        <translation>Éteindre</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Allumer</translation>
    </message>
    <message>
        <source>Airplane Mode settings</source>
        <translation>Paramètres du mode avion</translation>
    </message>
    <message>
        <source>Airplane mode disabled</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AirplaneModePlugin</name>
    <message>
        <source>Airplane Mode</source>
        <translation>Mode avion</translation>
    </message>
</context>
<context>
    <name>AppDragWidget</name>
    <message>
        <source>Remove</source>
        <translation>Retirer</translation>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>Paramètres Bluetooth</translation>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>Éteindre</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Allumer</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>Paramètres Bluetooth</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 connecté</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>Connexion...</translation>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>Eteint</translation>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>Ajouter une disposition de clavier</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>Date et heure</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>Affichage 12 heures</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>Affichage 24 heures</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>Réglages de l&apos;heure</translation>
    </message>
</context>
<context>
    <name>DialogManager</name>
    <message>
        <source>Are you sure you want to empty %1 items?</source>
        <translation>Êtes-vous sûr de vouloir supprimer %1 éléments ?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <source>This action cannot be restored</source>
        <translation>Cette action ne peut être restaurée</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown device</source>
        <translation>Périphérique inconnu</translation>
    </message>
    <message>
        <source>Unknown volume</source>
        <translation>Partition inconnue</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Disque</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Ouvrir</translation>
    </message>
    <message>
        <source>Unmount all</source>
        <translation>Tout démonter </translation>
    </message>
</context>
<context>
    <name>LauncherItem</name>
    <message>
        <source>Launcher</source>
        <translation>Lanceur</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Exit Safe Mode</source>
        <translation>Mode sans échec de sortie</translation>
    </message>
    <message>
        <source>Dock - Safe Mode</source>
        <translation>Dock - Mode sans échec</translation>
    </message>
    <message>
        <source>The Dock is in safe mode, please exit to show it properly</source>
        <translation>Le Dock est en mode sans échec, veuillez quitter pour l&apos;afficher correctement</translation>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Fashion Mode</source>
        <translation>Mode dock</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>Mode étendu</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Haut</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Bas</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Gauche</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Droite</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>Maintenir affiché</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>Maintenir caché</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>Masquage intelligemment</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Mode</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Emplacement</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Statut</translation>
    </message>
    <message>
        <source>Dock settings</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ModuleWidget</name>
    <message>
        <source>Size</source>
        <translation>Taille</translation>
    </message>
    <message>
        <source>Multiple Displays</source>
        <translation>Affichages multiples</translation>
    </message>
    <message>
        <source>Plugin Area</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Select which icons appear in the Dock</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Fashion mode</source>
        <translation>Mode dock</translation>
    </message>
    <message>
        <source>Efficient mode</source>
        <translation>Mode étendu </translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Mode</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Haut</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Bas</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Gauche</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Droite</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Emplacement</translation>
    </message>
    <message>
        <source>Keep shown</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Keep hidden</source>
        <translation>Maintenir caché</translation>
    </message>
    <message>
        <source>Smart hide</source>
        <translation>Masquer intelligemment</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Statut</translation>
    </message>
    <message>
        <source>Small</source>
        <translation>Petit</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>Grand</translation>
    </message>
    <message>
        <source>Show Dock</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>On screen where the cursor is</source>
        <translation>Sur l&apos;écran où se trouve le curseur</translation>
    </message>
    <message>
        <source>Only on main screen</source>
        <translation>Uniquement sur l&apos;écran principal</translation>
    </message>
</context>
<context>
    <name>MultitaskingPlugin</name>
    <message>
        <source>Multitasking View</source>
        <translation>Vue multitâche</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Détacher du dock</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>Clavier virtuel</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Paramètres</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power</source>
        <translation>Alimentation</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Options d&apos;alimentation</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>Capacité  %1, %2 minutes restantes</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>Capacité %1, %2 heures et %3 minutes restantes</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>En charge %1, %2 minutes avant la charge complète</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>En charge %1, %2 heures et %3 minutes avant la charge complète</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>Capacité %1</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>En charge %1</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>Capacité %1</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>Capacité %1, complètement chargé</translation>
    </message>
</context>
<context>
    <name>SettingsModule</name>
    <message>
        <source>Dock</source>
        <translation>Dock</translation>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
</context>
<context>
    <name>ShowDesktopPlugin</name>
    <message>
        <source>Show Desktop</source>
        <translation>Afficher le bureau</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Détacher du dock</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Power</source>
        <translation>Alimentation</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Arrêter</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Mise en veille </translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Mise en veille prolongée</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Verrouiller</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Déconnexion</translation>
    </message>
    <message>
        <source>Switch account</source>
        <translation>Changer de compte</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Options d&apos;alimentation</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Redémarrer</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Device</source>
        <translation>Périphérique</translation>
    </message>
</context>
<context>
    <name>SoundItem</name>
    <message>
        <source>Unmute</source>
        <translation>Réactiver le son</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Muet</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Paramètres sonores</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>Volume %1</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>Son</translation>
    </message>
</context>
<context>
    <name>TrashPlugin</name>
    <message>
        <source>Trash</source>
        <translation>Corbeille</translation>
    </message>
    <message>
        <source>Trash - %1 file</source>
        <translation>Corbeille - %1 fichier</translation>
    </message>
    <message>
        <source>Trash - %1 files</source>
        <translation>Corbeille - %1 fichiers</translation>
    </message>
    <message>
        <source>Move to Trash</source>
        <translation>Déplacer dans la corbeille</translation>
    </message>
</context>
<context>
    <name>TrashWidget</name>
    <message>
        <source>Open</source>
        <translation>Ouvrir</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>Vide</translation>
    </message>
</context>
</TS>
